;-------------------------------------------------------------------------
;			UART driver and interrupot handler
;-------------------------------------------------------------------------
;.equ	bauddivider = (xtal / baudrate + 8) / 16 - 1
;-------------------------------------------------------------------------
;				initialization
;-------------------------------------------------------------------------
uart_init:
;	ldi	a0, low(bauddivider)		;set baud rate
;	ldi	a1, high(bauddivider)
;
;input: a1:a0 = baud rate divider
set_baud:
	out		UBRRL, a0
#if defined(__ATmega128__)								;GL
	sts		UBRRH, a1
#else
	out		UBRRH, a1
#endif

	ldi		a0, 0				;no U2X, MPCM
	out		UCSRA, a0

#if defined(__ATmega128__)								;GL
	ldi		a0, 1<<UCSZ1^1<<UCSZ0	;8 Bit
	sts		UCSRC, a0
#else
	ldi		a0, 1<<URSEL^1<<UCSZ1^1<<UCSZ0	;8 Bit
	out		UCSRC, a0
#endif

	mov		rx_ptr, xl			;initialize rx buffer

	ldi		a0, 0x01
	ldi		a1, 0xA0
	movw	poly_hi:poly_lo, a1:a0		;set CRC polynom

	ldi		a0, 1<<RXEN^1<<TXEN^1<<RXCIE	;enable RX, TX
	out		UCSRB, a0
	ret
;-------------------------------------------------------------------------
;				Receive Interrupt
;-------------------------------------------------------------------------
URXCint:
	ldi		xh, high( rx_buff )
	in		ia0, UDR
	st		X+, ia0
;					calculate CRC
	in		savesreg, sreg
	eor		crc_lo, ia0
	ldi		ia0, 8
_crc1:	
	lsr		crc_hi
	ror		crc_lo
	brcc	_crc2
	eor		crc_lo, poly_lo
	eor		crc_hi, poly_hi
_crc2:	
	dec		ia0
	brne	_crc1
	out		sreg, savesreg		;+ 67 cycle
;
	reti				;81 cycle
;-------------------------------------------------------------------------
;				Receive Byte
;-------------------------------------------------------------------------
;output: a0 = byte
;
getchar:				;wait until one byte received
	cp		rx_ptr, xl
	breq	getchar
	mov		yl, rx_ptr
	ldi		yh, high( rx_buff )
	ld		a0, Y
	inc		rx_ptr
	ret
;-------------------------------------------------------------------------
;				Check if command received
;-------------------------------------------------------------------------
;Output: C = 1: command received
;	Y = command start
;	rx_ptr = after command end
;
rx_command:
	mov		yl, rx_ptr
_rxc1:	
	cp		yl, xl
	breq	_rxc3
	ldi		yh, high( rx_buff )	;wrap around
	ld		a0, Y+
	subi	a0, key_enter
	breq	_rxc2
	subi	a0, key_linefeed - key_enter
	brne	_rxc1
_rxc2:
	mov		a1, yl
	st		-Y, a0			;end of command = 0
	cpse	yl, rx_ptr		;ignore empty command
	sec
	mov		yl, rx_ptr		;point on start of command
	mov		rx_ptr, a1		;point after command
_rxc3:	
	ret
;-------------------------------------------------------------------------
;				transmit byte
;-------------------------------------------------------------------------
;input: a0 = byte
;
putchar:				;wait until tx buffer empty
	sbis	UCSRA, UDRE
	rjmp	putchar
	out		UDR, a0
	ret
;-------------------------------------------------------------------------
